@@ -1160,10 +1160,9 @@ void calcextents(genericptr *bboxgen, short *llx, short *lly,
 /* Calculate the bounding box of an object instance			*/
 /*----------------------------------------------------------------------*/
 
-void objinstbbox(objinstptr obbox, XPoint *npoints, Boolean expand)
+void objinstbbox(objinstptr obbox, XPoint *npoints, int extend)
 {
    XPoint points[4];
-   int extend = (expand) ? 4 : 0;
 
    points[0].x = points[1].x = obbox->bbox.lowerleft.x - extend;
    points[1].y = points[2].y = obbox->bbox.lowerleft.y + obbox->bbox.height
@@ -1256,7 +1255,7 @@ void calcbboxsingle(genericptr *bboxgen, objinstptr thisinst,
    switch(ELEMENTTYPE(*bboxgen)) {
 
       case(OBJINST):
-	 objinstbbox(TOOBJINST(bboxgen), npoints, False);
+	 objinstbbox(TOOBJINST(bboxgen), npoints, 0);
 
          for (j = 0; j < 4; j++) {
             bboxcalc(npoints[j].x, llx, urx);
@@ -1604,7 +1603,7 @@ nextgen:
    /* with only pin labels, the bounds may not have been changed from	*/
    /* their initial values.  If so, then don't touch the bounding box.	*/
 
-   if ((llx < urx) && (lly < ury)) {
+   if ((llx <= urx) && (lly <= ury)) {
       thisobj->bbox.lowerleft.x = llx;
       thisobj->bbox.lowerleft.y = lly;
       thisobj->bbox.width = urx - llx;
@@ -2079,7 +2078,7 @@ float UDrawRescaleBox(XPoint *corner)
 
       case OBJINST:
 	 rinst = (objinstptr)rgen;
-	 objinstbbox(rinst, newpoints, FALSE);
+	 objinstbbox(rinst, newpoints, 0);
 	 newpoints[4] = newpoints[0];
 	 mindist = LONG_MAX;
 	 for (i = 0; i < 4; i++) {
@@ -2103,7 +2102,7 @@ float UDrawRescaleBox(XPoint *corner)
 	 }
 	 else if (newscale < 0.1 * rgraph->scale) newscale = 0.1 * rgraph->scale;
 	 rinst->scale = newscale;
-	 objinstbbox(rinst, newpoints, FALSE);
+	 objinstbbox(rinst, newpoints, 0);
 	 rinst->scale = savescale;
          break;
    }
