@@ -796,7 +796,6 @@ void makepagebutton()
 
 void renamepage(short pagenumber)
 {
-   int page;
    objinstptr thisinst = xobjs.pagelist[pagenumber]->pageinst;
    char *pname, *plabel;
 
@@ -868,10 +867,10 @@ void setallstylemarks(u_short styleval)
       if (fillfactor < 100)
 	 sprintf(fstr, "%d", fillfactor);
       else
-	 strcat(fstr, "solid");
+	 strcpy(fstr, "solid");
    }
    else
-      strcat(fstr, "unfilled");
+      strcpy(fstr, "unfilled");
 
    switch (styleval & BORDERS) {
       case DASHED:
