@@ -1999,15 +1999,15 @@ short execcommand(short pflags, char *cmdptr)
 void defaultscript()
 {
    FILE *fd;
-   char *tmp_s = getenv((const char *)"XCIRCUIT_LIB_DIR");
+   char *tmp_s = getenv((const char *)"XCIRCUIT_SRC_DIR");
 
    flags = LIBOVERRIDE | LIBLOADED | FONTOVERRIDE;
 
-   if (!tmp_s) tmp_s = BUILTINS_DIR; 
+   if (!tmp_s) tmp_s = SCRIPTS_DIR; 
    sprintf(_STR2, "%s/%s", tmp_s, STARTUP_FILE);
 
    if ((fd = fopen(_STR2, "r")) == NULL) {
-      sprintf(_STR2, "%s/%s", BUILTINS_DIR, STARTUP_FILE);
+      sprintf(_STR2, "%s/%s", SCRIPTS_DIR, STARTUP_FILE);
       if ((fd = fopen(_STR2, "r")) == NULL) {
          Wprintf("Failed to open startup script \"%s\"\n", STARTUP_FILE);
 	 return;
