@@ -560,7 +560,8 @@ void charprint(char *sout, stringpart *strptr, int locpos)
 	    *sout = '\0';
 	 break;
       case FONT_NAME:
-	 sprintf(sout, "Font=%s", fonts[strptr->data.font].psname);
+	 sprintf(sout, "Font=%s", (strptr->data.font >= fontcount) ?
+		"(unknown)" : fonts[strptr->data.font].psname);
 	 break;
       case FONT_SCALE:
 	 sprintf(sout, "Scale=%3.2f", strptr->data.scale);
@@ -1320,7 +1321,8 @@ short UDrawChar(u_char code, short styles, short ffont, int groupheight, int pas
    short  localwidth;
    objinst charinst;
 
-   if (fonts[ffont].encoding == NULL) return 0;
+   if ((ffont >= fontcount) || (fonts[ffont].encoding == NULL))
+      return 0;
 
    alphapts[0].x = 0;
    alphapts[0].y = 0;
@@ -1454,12 +1456,14 @@ void UDrawString(labelptr drawlabel, int passcolor, objinstptr localinst)
 
 	  switch(strptr->type) {
 	     case FONT_NAME:
-		ffont = strptr->data.font;
-		fstyle = 0;		   /* style reset by font change */
-	        if (baseline == newpoint.y) {  /* set top-level font and style */
-	           oldfont = ffont;
-	           oldstyle = fstyle;
-	        }
+		if (strptr->data.font < fontcount) {
+		   ffont = strptr->data.font;
+		   fstyle = 0;		   /* style reset by font change */
+	           if (baseline == newpoint.y) {  /* set top-level font and style */
+	              oldfont = ffont;
+	              oldstyle = fstyle;
+	           }
+		}
 		
 		/* simple boldface technique for derived fonts */
 
