@@ -67,7 +67,7 @@
 /*----------------------------------------------------------------------*/
 
 short	 popups;      /* total number of popup widgets on the screen */
-Boolean	 pressmode;   /* Whether we are in a press & hold state */
+int	 pressmode;   /* Whether we are in a press & hold state */
 
 xcWidget   top;
 xcWidget   message1, message2, message3, toolbar, overlay = NULL;
@@ -2023,7 +2023,7 @@ int main(int argc, char **argv)
 
    for (k = argc - 1; k > 0; k--) {
       if (!strncmp(argv[k], "-2", 2)) {
-	 pressmode = True;	/* 2-button mouse indicator */
+	 pressmode = 1;		/* 2-button mouse indicator */
 	 break;
       }
    }
@@ -2047,7 +2047,7 @@ int main(int argc, char **argv)
 #endif
 
    loadrcfile();
-   pressmode = False;	/* Done using this to mark 2-button mouse mode */
+   pressmode = 0;	/* Done using this to mark 2-button mouse mode */
 
    composelib(PAGELIB);	/* make sure we have a valid page list */
    composelib(LIBLIB);	/* and library directory */
